==> haskell-natural-transformation-0.4.1-118.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-natural-transformation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 natural-transformation
version:              0.4.1
visibility:           public
id:                   natural-transformation-0.4.1-67lCzqcYSOG6noQ1DnGCNi
key:                  natural-transformation-0.4.1-67lCzqcYSOG6noQ1DnGCNi
license:              BSD-3-Clause
copyright:            Copyright (c) 2015-2016 The University of Kansas
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            Provisional
homepage:             https://github.com/ku-fpg/natural-transformation
synopsis:             A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.

    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.

category:             Control
abi:                  873c09c071c490c60f77b6131d121e96
exposed:              True
exposed-modules:      Control.Natural Control.Natural.RULES Control.Object
import-dirs:          /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-natural-transformation
hs-libraries:         HSnatural-transformation-0.4.1-67lCzqcYSOG6noQ1DnGCNi
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock

haddock-html:         /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-natural-transformation-0.4.1-119-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-natural-transformation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 natural-transformation
version:              0.4.1
visibility:           public
id:                   natural-transformation-0.4.1-B3xlX0nrik296TZmCy6x3B
key:                  natural-transformation-0.4.1-B3xlX0nrik296TZmCy6x3B
license:              BSD-3-Clause
copyright:            Copyright (c) 2015-2016 The University of Kansas
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            Provisional
homepage:             https://github.com/ku-fpg/natural-transformation
synopsis:             A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.

    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.

category:             Control
abi:                  0bc8d3e7e17dcba56ce48d78dd01ba84
exposed:              True
exposed-modules:      Control.Natural Control.Natural.RULES Control.Object
import-dirs:          /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-natural-transformation
hs-libraries:         HSnatural-transformation-0.4.1-B3xlX0nrik296TZmCy6x3B
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock

haddock-html:         /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
